@@ -16,7 +16,7 @@
  * 02110-1301, USA.
  */
 
-#include <cairomm/cairommconfig.h>
+#include <cairommconfig.h>
 #include <cairomm/context.h>
 #include <cairomm/context_private.h>
 #include <cairomm/private.h>
@@ -29,9 +29,7 @@
 #endif 
 
 /* Solaris et. al. need math.h for M_PI too */
-#ifdef HAVE_MATH_H
-# include <math.h>
-#endif
+#include <cmath>
 
 using namespace Cairo::Private;
 
