@@ -307,6 +307,9 @@ public:
    */
   void transform(const Matrix& matrix);
 
+  /* To keep 1.6.x ABI  */
+  void transform(const cairo_matrix_t& matrix);
+
   /** Modifies the current transformation matrix (CTM) by setting it equal to
    * matrix.
    *
@@ -314,6 +317,9 @@ public:
    */
   void set_matrix(const Matrix& matrix);
 
+  /* To keep 1.6.x ABI  */
+  void set_matrix(const cairo_matrix_t& matrix);
+
   /** Resets the current transformation matrix (CTM) by setting it equal to the
    * identity matrix. That is, the user-space and device-space axes will be
    * aligned and one user-space unit will transform to one device-space unit.
@@ -471,6 +477,10 @@ public:
    *
    * @param dx	the X offset
    * @param dy	the Y offset
+   *
+   * It is an error to call this function with no current point. Doing
+   * so will cause this to shutdown with a status of
+   * CAIRO_STATUS_NO_CURRENT_POINT. Cairomm will then throw an exception.
    */
   void rel_move_to(double dx, double dy);
 
@@ -490,6 +500,10 @@ public:
    *
    * @param dx	the X offset to the end of the new line
    * @param dy	the Y offset to the end of the new line
+   *
+   * It is an error to call this function with no current point. Doing
+   * so will cause this to shutdown with a status of
+   * CAIRO_STATUS_NO_CURRENT_POINT. Cairomm will then throw an exception.
    */
   void rel_line_to(double dx, double dy);
 
@@ -514,6 +528,10 @@ public:
    * @param dy2	the Y offset to the second control point
    * @param dx3	the X offset to the end of the curve
    * @param dy3	the Y offset to the end of the curve
+   *
+   * It is an error to call this function with no current point. Doing
+   * so will cause this to shutdown with a status of
+   * CAIRO_STATUS_NO_CURRENT_POINT. Cairomm will then throw an exception.
    */
   void rel_curve_to(double dx1, double dy1, double dx2, double dy2, double dx3, double dy3);
 
@@ -703,6 +721,10 @@ public:
   void get_font_matrix(Matrix& matrix) const;
   void set_font_options(const FontOptions& options);
 
+  /* To keep 1.6.x ABI  */
+  void set_font_matrix(const cairo_matrix_t& matrix);
+  void get_font_matrix(cairo_matrix_t& matrix) const;
+
   //TODO: Documentation.
   /**
    * @since 1.8
@@ -815,6 +837,10 @@ public:
    * @param matrix	return value for the matrix
    */
   void get_matrix(Matrix& matrix);
+
+  /* To keep 1.6.x ABI  */
+  void get_matrix(cairo_matrix_t& matrix);
+
   /** @since 1.8
    */
   Matrix get_matrix() const;
