@@ -31,8 +31,8 @@ ScaledFont::ScaledFont(cobject* cobj, bool has_reference)
     m_cobject = cairo_scaled_font_reference(cobj);
 }
 
-ScaledFont::ScaledFont(const RefPtr<FontFace>& font_face, const Matrix& font_matrix,
-                       const Matrix& ctm, const FontOptions& options)
+ScaledFont::ScaledFont(const RefPtr<FontFace>& font_face, const cairo_matrix_t& font_matrix,
+                       const cairo_matrix_t& ctm, const FontOptions& options)
 {
   m_cobject =
     cairo_scaled_font_create(font_face->cobj(),
@@ -54,6 +54,12 @@ RefPtr<ScaledFont> ScaledFont::create(const RefPtr<FontFace>& font_face, const M
   return RefPtr<ScaledFont>(new ScaledFont(font_face, font_matrix, ctm, options));
 }
 
+RefPtr<ScaledFont> ScaledFont::create(const RefPtr<FontFace>& font_face, const cairo_matrix_t& font_matrix,
+    const cairo_matrix_t& ctm, const FontOptions& options)
+{
+  return RefPtr<ScaledFont>(new ScaledFont(font_face, font_matrix, ctm, options));
+}
+
 void ScaledFont::extents(FontExtents& extents) const
 {
   cairo_scaled_font_extents(m_cobject, static_cast<cairo_font_extents_t*>(&extents));
@@ -103,12 +109,25 @@ void ScaledFont::get_font_matrix(Matrix& font_matrix) const
   check_object_status_and_throw_exception(*this);
 }
 
+void ScaledFont::get_font_matrix(cairo_matrix_t& font_matrix) const
+{
+  cairo_scaled_font_get_font_matrix(m_cobject,
+                                    &font_matrix);
+  check_object_status_and_throw_exception(*this);
+}
+
 void ScaledFont::get_ctm(Matrix& ctm) const
 {
   cairo_scaled_font_get_ctm(m_cobject, &ctm);
   check_object_status_and_throw_exception(*this);
 }
 
+void ScaledFont::get_ctm(cairo_matrix_t& ctm) const
+{
+  cairo_scaled_font_get_ctm(m_cobject, &ctm);
+  check_object_status_and_throw_exception(*this);
+}
+
 FontType ScaledFont::get_type() const
 {
   cairo_font_type_t font_type = cairo_scaled_font_get_type(m_cobject);
